/*---------------------------------------
 * iservpsu.h
 *--------------------------------------
 */
/*
 * $RCSfile: iservpsu.h,v $
 * $Revision: 1.3 $
 * $Date: 1998/08/05 20:05:00 $
 *
 * $Header: //Iservd/iservpsu.h#1 $
 * 
 * $Log: iservpsu.h,v $
 * Revision 1.3  1998/08/05 20:05:00  chuckh
 * Changed declaration of close psu to be classic C style (no prototyping)
 *
 * Revision 1.2  1998/08/04 21:35:04  chuckh
 * Added declaration for ClosePSU
 *
 * Revision 1.1  1998/07/31 21:13:29  chuckh
 * Initial revision
 *
 */

#define FNAME_MAX 90

typedef struct _servpsu {
	int psuFlag;		/* Various Booleans: see below */
	int psuMaster;		/* FD of the master port */
	int psuSlave;		/* FD of the slave port */
				/* The next two are only used with autopush */
	int psuMajor;		/* Major device number of slave */
	int psuMinor;		/* Minor device number of slave */
	int psuAdm;		/* FD of the ADM device */
	char psuMasterName[FNAME_MAX];	/* Name of the master port */
					/* (Or the clone master port) */
	char psuSlaveName[FNAME_MAX];	/* Name of the slave port */
	char psuLink[FNAME_MAX];	/* Full path name of the link */
} servpsu_t;

#define	PSU_MOPEN	1	/* Master port opened: psuMaster valid */
#define	PSU_SOPEN	2	/* Slave port opened: psuMaster valid */
#define PSU_MNAME	4	/* Master name is non-clone */
#define PSU_SNAME	8	/* Slave name is valid */
#define PSU_ERROR	0x10	/* There was an error */
#define PSU_SLINK	0x20	/* Slave is Linked */
#define PSU_PERM	0x40	/* PERMANENT CONNECTION: Don't care whether
				 * the slave device is closed.
				 */
#define PSU_CLEAN	0x80	/* Slave port will need to be closed so
				 * we can detect the other process closing.
				 */
#define PSU_DIDAUTO	0x100	/* Prevents auto-push configuration from
				 * occurring multiple times unneededly.
				 * also implies psuAdm is open.
				 */
#define PSU_SRAW	0x200	/* Initialize slave port to uncooked mode */
#define PSU_OCOOK	0x400	/* Initialize slave port to output cooked only */
#define PSU_IGCLOSE	0x800	/* For temp connections, ignore slave close */
#define PSU_DELETE	0x1000	/* delete device linked to pty slave on exit */



/*----------------------------------------
 * External Declarations:
 * There are just four functions which are
 * exported to the outside world.
 *	initPsu(psu, opt)
 *	buildPseudoPort(psu)
 *	cleanPseudo(psu)
 *	closeSlave(psu)	
 *----------------------------------------
 */

extern void initPsu ARGS((servpsu_t *, servopts_t *));
	/* initPsu at program startup after options are parsed */

extern int buildPseudo ARGS((servpsu_t *));
	/* buildPseudo at startup, OR to send a sighup to
	 * the process using the slave device, and then rebuild
	 * the master-slave pair.
	 */

extern int cleanPseudo ARGS((servpsu_t *));
	/* Get rid of any auto-push stuff that would otherwise
	 * persist when our process exits.
	 */

extern int reopenSlave ARGS((servpsu_t *));
	/* If slave port is closed, re-open it */

extern int closeSlave ARGS((servpsu_t *));
	/* If slave port is open, close it and return true, else false */
	
extern	void	ClosePSU ARGS((int fd));

