/*
 *
 * $RCSfile: newjob.c,v $
 * $Revsion$
 * $Date: 1998/08/07 14:50:10 $
 *
 * This will create a child structure based on a command line.
 *
 * The format of an input line
 *    id cmd [arg [...]]
 * where
 *    id is a unique string identifier for this command
 *    cmd is the command to execute along with any arguments.
 *            
 * The format of this line can be arbitrary, but for right now
 * it's simply interpreted as a series of args.
 *
 * $Header: //Iservd/newjob.c#1 $
 * 
 * $Log: newjob.c,v $
 * Revision 1.3  1998/08/07 14:50:10  chuckh
 * Fixed an rcs header
 *
 * Revision 1.2  1998/08/05 20:11:24  chuckh
 * Changed definition from ANSI C to classic C.
 *
 * Revision 1.1  1998/08/04 20:21:20  chuckh
 * Initial revision
 *
 * Revision 1.2  1998/07/31 20:53:29  chuckh
 * Cleaned up RCS headers
 *
 * Revision 1.1  1998/07/31 20:35:27  chuckh
 * Initial revision
 *
 */

#include <string.h>
#include "ss.h"

JOB	*
NewJob (cmdLine)
char	*cmdLine;
{
	JOB		*cur;
	int		argCount = 0;
	int		optionCount = 0;
	char	*curTok, *cp;
	char	*machine, *port;

	/*
	 * Now create a job node
	 */
	if ((cur = (JOB *) malloc(sizeof(*cur))) == (JOB *) 0)
	{
		return (JOB *) 0;
	}
	memset(cur, 0, sizeof(*cur));
	/* From this point on, FreeJob() can be called to free a node */

	/*
	 * Get the identifier for this command
	 * For iservd, this gets the pseudo-tty name
	 */
	if ((curTok = GetToken(cmdLine)) == (char *) 0
	 || (cur->id = strdup(curTok)) == (char *) 0)
	{
		FreeJob(cur);
		return (JOB *) 0;
	}
	/* If the pseudo-tty ends with a colon, delete the colon */
	if (*(cp = cur->id+(strlen(cur->id)-1)) == ':')
		*cp = 0;


	/*
	 * The next thing in the line should be the name of the
	 * power rack.
	 */
	if ((curTok = GetToken((char *) 0)) == (char *) 0
	 || (machine = strdup(curTok)) == (char *) 0)
	{
		FreeJob(cur);
		return (JOB *) 0;
	}


	/*
	 * Next is the port number for the target power rack
	 */
	if ((curTok = GetToken((char *) 0)) == (char *) 0
	 || (port = strdup(curTok)) == (char *) 0)
	{
		free(machine);
		FreeJob(cur);
		return (JOB *) 0;
	}


	/*
	 * The remainder of the line consists of options to pass on
	 * to the child. All of these options need to appear
	 * in the command line before the pseudo-tty, machine, and port.
	 */
	while (1)
	{
		char	**newArgpp;
		char	*cp;

		/*
		 * Get the next argument.
		 */
		switch (optionCount)
		{
			char	*lastSlash, *dot;

		/* 
		 * The first argument should be the full name of this
		 * command with a 'c' appended.
		 */
		case 0:
			/* Make a working copy of the absolute argv0 */
			if ((cp = strdup(absArgv0)) == (char *) 0)
			{
				free(machine);
				free(port);
				FreeJob(cur);
				return (JOB *) 0;
			}

			/* Make some room for the new command line */
			if ((curTok = (char *) malloc(strlen(absArgv0)+2)) == (char *) 0)
			{
				free(machine);
				free(port);
				FreeJob(cur);
				return (JOB *) 0;
			}

			/* Locate the last slash */
			if (lastSlash = strrchr(cp, '/'))
				dot = strchr(lastSlash, '.');
			else
				dot = strchr(cp, '.');

			/*
			 * IF there's a dot, stick a 'c' just prior to the dot.
			 */
			if (dot)
			{
				*dot = 0;
				sprintf(curTok, "%sc.%s", cp, dot+1);
			}

			/* Otherwise, just append a c to the existing name */
			else
				sprintf(curTok, "%sc", cp);

			free(cp);
			break;

		case 1:
			/* With done with our temparary argv0. get rid of it */
			free(curTok);

			/* Fall through */

		default:
			/*
			 * If something goes wrong with a token, assume we've
			 * reached the end of the options. Now it's time to
			 * start appending real arguments to the command
			 * line.
			 */
			if ((curTok = GetToken((char *) 0)) == (char *) 0)
			{
				optionCount = 100;

				/* The first non-option is the pseudo-tty */
				curTok = cur->id;
			}
			break;

		case 101:
			curTok = machine; /* argv[2]= the machine name */
			break;

		case 102:
			free(machine);	/* Done with it */
			curTok = port;	/* Next is the port */
			break;

		case 103:
			free(port);		/* Done with the port */
			return (cur);

		}

		/*
		 * Allocate room in the list of arguments for another
		 * argument and a null terminator.
		 */
		if (argCount == 0)
			newArgpp = (char **) malloc((argCount+2) * sizeof(*cur->args));
		else
			newArgpp = (char **) realloc(cur->args,
				(argCount+2) * sizeof(*cur->args));
		if (newArgpp == (char **) 0)
		{
			switch(optionCount)
			{
			case 100:	free(curTok);
			case 101:	free(machine);
			case 102:	free(port);
			}
			FreeJob(cur);
			return (JOB *) 0;
		}
		cur->args = newArgpp;

		/*
		 * Make sure the new list is terminated and 
		 * locate a *copy* of the current token.
		 */
		newArgpp[argCount+1] = (char *) 0;
		if ((newArgpp[argCount] = strdup(curTok)) == (char *) 0)
		{
			switch(argCount)
			{
			case 0:	free(curTok);
			case 1:	
			case 2:	free(machine);
			case 3:	free(port);
			}
			FreeJob(cur);
			return (JOB *) 0;
		}

		++argCount;
		++optionCount;
	}

	return (cur);
}
