/*
 *
 * $RCSfile: ss.h,v $
 * $Version$
 * $Date: 1998/08/05 20:15:35 $
 *
 * Super server header file.
 * Use this program to change the way a header file is interpreted.
 *
 * By use of functions internal to ss.c, lines beginning with '#'
 * and blank lines are considered comments.
 *
 * $Header: //Iservd/ss.h#1 $
 * 
 * $Log: ss.h,v $
 * Revision 1.8  1998/08/05 20:15:35  chuckh
 * Replaced function prototypes (ANSI C) with function declarations
 * per classic C.
 *
 * Revision 1.7  1998/08/04 20:11:56  chuckh
 * Added flag used in reconfig procedure
 *
 * Revision 1.6  1998/08/03 16:03:55  chuckh
 * Oops.  mis-declared absolute path name external
 *
 * Revision 1.5  1998/08/03 15:42:49  chuckh
 * Separated Log() into its own module
 *
 * Revision 1.4  1998/08/03 14:56:46  chuckh
 * Added declaration for FreeJob
 *
 * Revision 1.3  1998/08/03 14:31:43  chuckh
 * Added absArgv0 to list of externals
 *
 * Revision 1.2  1998/07/31 20:53:29  chuckh
 * Cleaned up RCS headers
 *
 * Revision 1.1  1998/07/31 20:35:12  chuckh
 * Initial revision
 *
 */

#include <sys/types.h>

typedef	struct	cld_t	{
	struct	cld_t	*next, *prev;
	char	*id;			/* Uniquely identifies this command */
	char	**args;			/* command and it's args */
	pid_t	pid;			/* Process ID of running command */
	time_t	timeOfDeath;	/* When it most recently died */
	uint	dontRespawn:1,
			obsolete:1;		/* Used during Reconfigure */
		
} JOB;

/*
 * This function needs to be defined in an external module
 *
 * It gets passed a line from the configuration file, and returns a
 * pointer to a structure locating a JOB.  *id and **args should be
 * stored in the heap as well as all elements of *args[]. All other
 * fields must be left a null.
 *
 */
JOB		*NewJob();
char	*GetToken();
void	FreeJob();
void	Log();

#define DEFAULT_CONF_FILE	"/etc/iservd.conf"

#ifndef	SS_C
extern	int		debug;
extern	char	*debugArg;	/* Used only if debug != 0 */
extern	char	absArgv0[];	/* absolute path to the name of running program */

#endif
